Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func HandleDeferError ¶
HandleDeferError calls a deferred function and updates the provided error pointer with any error that occurs during the call. Argument requirements:
- The deferred function MUST NOT be nil; if it is nil, an error is logged.
- The error pointer MUST NOT be nil; if it is nil, an error is logged. The passed error will be preserved but may be wrapped in a new error that includes the error from the deferred function.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.