Documentation
¶
Index ¶
Constants ¶
const ( MountRWOption string = ":z" MountROOption string = ":z,ro" PrivilegedFlag string = "--privileged" InteractiveFlag string = "-i" )
Variables ¶
This section is empty.
Functions ¶
func RunDocker ¶
func RunDocker(ctx context.Context, cmdFactory opctx.CmdFactory, dockerArgs []string, containerTag string, entryPointArgs []string, logFile string, logFilter func(context.Context, string), ) (string, error)
RunDocker runs a docker command with the specified arguments and returns the stdout output as a string. It can also capture output from a log file (logFile) in real-time, filter it (logFilter) and send it to the console.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.