magecheckfix

package
v0.1.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 18, 2026 License: MIT Imports: 10 Imported by: 0

Documentation

Index

Constants

const (
	TargetAll      = "all"
	TargetMod      = "mod"
	TargetLint     = "lint"
	TargetStatic   = "static"
	TargetLicenses = "licenses"
)

Meta targets for the checks and fixes.

Variables

var (
	ErrCheck    = errors.New("check failed")
	ErrFix      = errors.New("fix failed")
	ErrLint     = errors.New("lint failed")
	ErrToolPath = errors.New("path not set for tool")
)

Functions

func Check

func Check(target string) error

Check one of: [all, mod, lint, static, licenses]. BASH-COMPLETION: This is scanned by the bash completion script, keep it in sync with the script.

func Fix

func Fix(target string) error

Fix one of: [all, mod, lint]. BASH-COMPLETION: This is scanned by the bash completion script, keep it in sync with the script.

Types

This section is empty.

Jump to